@@ -2,10 +2,12 @@
 
 from .fix_message import FixMessage, FixMessageFactory
 from .loader import load_yaml_protocol, load_quickfix_protocol
+from .types import ValueType
 
 __all__ = [
     'FixMessage',
     'FixMessageFactory',
     'load_quickfix_protocol',
-    'load_yaml_protocol'
+    'load_yaml_protocol',
+    'ValueType'
 ]
