@@ -1,8 +1,11 @@
-"""YAML Loader"""
+"""A loader for YAML formated metadata"""
+
+from typing import Mapping, Optional
 
 from ruamel.yaml import YAML
 
 from ..meta_data import ProtocolMetaData
+from ..types import ValueType
 
 from .loader import load_protocol
 
@@ -12,7 +15,7 @@ def load_yaml_protocol(
         *,
         is_millisecond_time: bool = True,
         is_float_decimal: bool = False,
-        is_bool_enum: bool = False
+        is_type_enum: Optional[Mapping[ValueType, bool]] = None
 ) -> ProtocolMetaData:
     """Load a YAML style protocol file
 
@@ -22,8 +25,8 @@ def load_yaml_protocol(
             Defaults to True.
         is_float_decimal (bool, optional): If true use Decimal for floating
             point numbers. Defaults to False.
-        is_bool_enum (bool, optional): If true use enum names for booleans.
-            Defaults to False.
+        is_type_enum (Optional[Mapping[ValueType, bool]], optional): Map
+            controlling serialization to enums. Defaults to None.
 
     Returns:
         ProtocolMetaData: The protocol meta data.
@@ -34,5 +37,5 @@ def load_yaml_protocol(
             yaml.load(file_ptr),
             is_millisecond_time=is_millisecond_time,
             is_float_decimal=is_float_decimal,
-            is_bool_enum=is_bool_enum
+            is_type_enum=is_type_enum
         )
